@@ -118,10 +118,23 @@ log = logging.getLogger(__name__)
 
 agent_log = None
 
-VERSION = '0.7.6'
+VERSION = '0.8.0'
 DEFAULT_ENDPOINT = 'https://api.rollbar.com/api/1/'
 DEFAULT_TIMEOUT = 3
 
+DEFAULT_LOCALS_SIZES = {
+    'maxdict': 10,
+    'maxarray': 10,
+    'maxlist': 10,
+    'maxtuple': 10,
+    'maxset': 10,
+    'maxfrozenset': 10,
+    'maxdeque': 10,
+    'maxstring': 100,
+    'maxlong': 40,
+    'maxother': 100,
+}
+
 # configuration settings
 # configure by calling init() or overriding directly
 SETTINGS = {
@@ -143,19 +156,8 @@ SETTINGS = {
     },
     'allow_logging_basic_config': True,  # set to False to avoid a call to logging.basicConfig()
     'locals': {
-        'enabled': False,
-        'sizes': {
-            'maxdict': 10,
-            'maxarray': 10,
-            'maxlist': 10,
-            'maxtuple': 10,
-            'maxset': 10,
-            'maxfrozenset': 10,
-            'maxdeque': 10,
-            'maxstring': 100,
-            'maxlong': 40,
-            'maxother': 100,
-        }
+        'enabled': True,
+        'sizes': DEFAULT_LOCALS_SIZES
     }
 }
 
@@ -178,14 +180,16 @@ def init(access_token, environment='production', **kw):
                  'staging', 'yourname'
     **kw: provided keyword arguments will override keys in SETTINGS.
     """
-    global agent_log, _initialized, _repr
+    global SETTINGS, agent_log, _initialized, _repr
 
     if not _initialized:
         _initialized = True
 
         SETTINGS['access_token'] = access_token
         SETTINGS['environment'] = environment
-        SETTINGS.update(kw)
+
+        # Merge the extra config settings into SETTINGS
+        SETTINGS = dict_merge(SETTINGS, kw)
 
         if SETTINGS.get('allow_logging_basic_config'):
             logging.basicConfig()
@@ -743,6 +747,9 @@ def _scrub_request_url(url_string):
 
     # use dash for replacement character so it looks better since it wont be url escaped
     scrubbed_qs_params = _scrub_obj(qs_params, replacement_character='-')
+
+    # Make sure the keys and values are all utf8-encoded strings
+    scrubbed_qs_params = dict((_to_str(k), list(map(_to_str, v))) for k, v in scrubbed_qs_params.items())
     scrubbed_qs = urlencode(scrubbed_qs_params, doseq=True)
 
     scrubbed_url = (url.scheme, url.netloc, url.path, url.params, scrubbed_qs, url.fragment)
@@ -761,7 +768,7 @@ def _scrub_obj(obj, replacement_character='*'):
     scrub_fields = set(SETTINGS['scrub_fields'])
 
     def _scrub(obj, k=None):
-        if k is not None and k.lower() in scrub_fields:
+        if k is not None and _in_scrub_fields(k, scrub_fields):
             if isinstance(obj, string_types):
                 return replacement_character * len(obj)
             elif isinstance(obj, list):
@@ -780,6 +787,26 @@ def _scrub_obj(obj, replacement_character='*'):
     return _scrub(obj)
 
 
+def _to_str(x):
+    try:
+        return str(x)
+    except UnicodeEncodeError:
+        try:
+            return unicode(x).encode('utf8')
+        except UnicodeEncodeError:
+            return x.encode('utf8')
+
+
+def _in_scrub_fields(val, scrub_fields):
+    val = _to_str(val).lower()
+    for field in set(scrub_fields):
+        field = _to_str(field)
+        if field == val:
+            return True
+
+    return False
+        
+
 def _local_repr(obj):
     orig = repr(obj)
     reprd = _repr.repr(obj)
